Skip to contents

Restores all colors, parameters, and theme overrides to the package defaults.

Usage

pepvet_plot_config_reset()

Value

Invisibly returns a list with current palette, params, and theme.

Examples

if (requireNamespace("ggplot2", quietly = TRUE)) {
  pepvet_plot_config(palette = list(brand = "#004488"))
  pepvet_plot_config_reset()
}